#!/usr/bin/env python

"A WebStack questionnaire application."

import WebStack.Generic
from XSLForms.Resources.WebResources import \
    XSLFormsResource, output, resources, prepare_resources as xslforms_prepare_resources
import os

# Site map imports.

from WebStack.Resources.ResourceMap import MapResource
from WebStack.Resources.Selectors import EncodingSelector
from WebStack.Resources.Static import DirectoryResource

# Configuration settings.

encoding = "utf-8"

# Resource classes.

class QuestionnaireEditorResource(XSLFormsResource):

    "A resource providing a questionnaire editor."

    resource_dir = resources(__file__)
    template_resources = {
        "questionnaire" : output("question_template.xhtml")
        }

    def select_activity(self, trans, form):
        form.set_activity("questionnaire")

    def respond_to_input(self, trans, form):

        parameters = form.get_parameters()
        selectors = form.get_selectors()
        questionnaire = form.get_document()

        self.remove_elements(selectors.get("remove-question"))
        self.add_elements(selectors.get("add-choice"), "choice")
        self.remove_elements(selectors.get("remove-choice"))

        # Add questions using the normal request parameter.

        if parameters.has_key("add-question"):
            new_question = questionnaire.ownerDocument.createElementNS(None, "question")
            questionnaire.xpath("questionnaire")[0].appendChild(new_question)

        # Send a response according to certain parameters.
        # When exported, an XML version of the data is returned.

        if parameters.has_key("export"):
            trans.set_content_type(WebStack.Generic.ContentType("text/xml", encoding))
            questionnaire.toStream(trans.get_response_stream(), trans.get_response_stream_encoding())
            raise WebStack.Generic.EndOfResponse

# Site map initialisation.

def get_site():

    "Return a simple Web site resource."

    # Get the main resource and the directory used by the application.

    questionnaire_resource = QuestionnaireEditorResource()
    directory = questionnaire_resource.resource_dir

    # Make a simple Web site.

    resource = MapResource({
        # Static resources:
        "styles" : DirectoryResource(os.path.join(directory, "styles"), {"css" : "text/css"}),
        # Main page:
        "" : questionnaire_resource
        })

    return EncodingSelector(resource, encoding)

# Resource preparation ahead of time - useful for making installations.

def prepare_resources():
    for cls in [QuestionnaireEditorResource]:
        xslforms_prepare_resources(cls)

# vim: tabstop=4 expandtab shiftwidth=4
